<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * All the steps to restore mod_dynamo are defined here.
 *
 * @package     mod_dynamo
 * @category    backup
 * @copyright   2019 UCLouvain
 * @author      Dominique Palumbo
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

// For more information about the backup and restore process, please visit:.
// https://docs.moodle.org/dev/Backup_2.0_for_developers.
// https://docs.moodle.org/dev/Restore_2.0_for_developers.

/**
 * Defines the structure step to restore one mod_dynamo activity.
 */
class restore_dynamo_activity_structure_step extends restore_activity_structure_step {

    /**
     * Defines the structure to be restored.
     *
     * @return restore_path_element[].
     */
    protected function define_structure() {
        $paths = array();
        $userinfo = $this->get_setting_value('userinfo');

        $dynamo = new restore_path_element('dynamo', '/activity/dynamo');
        $paths[] = $dynamo;

        if ($userinfo) {
            $eval = new restore_path_element('dynamo_eval', '/activity/dynamo/evals/eval');
            $paths[] = $eval;
        }

        return $this->prepare_activity_structure($paths);
    }

    /**
     * Process the structure dynamo before restore
     *
     *
     * @param object $data structure of data to restore.
     */
    protected function process_dynamo($data) {
        global $DB;

        $data = (object)$data;
        $data->course = $this->get_courseid();
        $data->groupingid = $this->get_mappingid('grouping', $data->groupingid);

        // Insert the dynamo record.
        $newid = $DB->insert_record('dynamo', $data);

        // Immediately after inserting "activity" record, call this.
        $this->apply_activity_instance($newid);
    }

    /**
     * Process the structure eval before restore
     *
     *
     * @param object $data structure of data to restore.
     */
    protected function process_dynamo_eval($data) {
        global $DB;
        $data = (object)$data;
        $oldid = $data->id;

        $data->builder = $this->get_new_parentid('dynamo');
        
        // Bugfix:The user id of a group evaluation is a group id not a user id.
        if ($data->critgrp == 1) {
            $data->userid = $this->get_mappingid('group', $data->userid);
        } else {
            $data->userid = $this->get_mappingid('user', $data->userid);
        }
        $data->evalbyid = $this->get_mappingid('user', $data->evalbyid);

        $newevalid = $DB->insert_record('dynamo_eval', $data);

        $this->set_mapping('dynamo_eval', $oldid, $newevalid);
    }

    /**
     * Defines post-execution actions.
     */
    protected function after_execute() {
        $this->add_related_files('mod_dynamo', 'intro', null);
    }
}
