<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Display information about all the mod_dynamo modules in the requested course.
 *
 * @package     mod_dynamo
 * @copyright   2019 UCLouvain
 * @author      Dominique Palumbo
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(dirname(__FILE__).'/../../config.php');
require_once(dirname(__FILE__).'/lib.php');

$id = required_param('id', PARAM_INT);
$course = $DB->get_record('course', array('id' => $id), '*', MUST_EXIST);

require_course_login($course);

$params = array(
    'context' => context_course::instance($course->id)
);
$event = \mod_dynamo\event\course_module_instance_list_viewed::create($params);
$event->add_record_snapshot('course', $course);
$event->trigger();

$strdynamos = get_string('modulenameplural', 'dynamo');

$PAGE->requires->css('/mod/dynamo/styles.css');
$PAGE->set_url('/mod/dynamo/index.php', array('id' => $id));
$PAGE->set_pagelayout('incourse');
$PAGE->navbar->add($strdynamos);
$PAGE->set_title($strdynamos);
$PAGE->set_heading($course->fullname);
echo $OUTPUT->header();

if (! $dynamos = get_all_instances_in_course('dynamo', $course)) {
    echo $OUTPUT->heading(get_string('thereareno', 'moodle', $strdynamos), 2);
    echo $OUTPUT->continue_button(new moodle_url('/course/view.php', ['id' => $course->id]));
    echo $OUTPUT->footer();
    die;
}

$timenow = time();
$strname = get_string('name');
$strweek = get_string('week');
$strtopic = get_string('topic');

$table = new html_table();
if ($course->format == 'weeks') {
    $table->head = array ($strweek, $strname);
    $table->align = array ('center', 'left');
} else if ($course->format == 'topics') {
    $table->head = array ($strtopic, $strname);
    $table->align = array ('center', 'left', 'left', 'left');
} else {
    $table->head = array ($strname);
    $table->align = array ('left', 'left', 'left');
}

foreach ($dynamos as $dynamo) {
    if (!$dynamo->visible) {
        // Show dimmed if the mod is hidden.
        $link = '<a class="dimmed" href="view.php?id='.$dynamo->coursemodule.'">'.format_string($dynamo->name).'</a>';
    } else {
        // Show normal if the mod is visible.
        $link = '<a href="view.php?id='.$dynamo->coursemodule.'">'.format_string($dynamo->name).'</a>';
    }

    if ($course->format == 'weeks' || $course->format == 'topics') {
        $table->data[] = array ($dynamo->section, $link);
    } else {
        $table->data[] = array ($link);
    }
}

echo $OUTPUT->heading($strdynamos, 2);
echo html_writer::table($table);
echo('<script>
$(document).ready(function() {
$(".fa-shield").addClass("fa-shield-alt").removeClass("fa-shield");
$(".fa-check-square-o").addClass("fa-check-square").removeClass("fa-check-square-o");
$(".fa-folder-o").addClass("fa-folder").removeClass("fa-folder-o");
$(".fa-tachometer").addClass("fa-tachometer-alt").removeClass("fa-tachometer");
$(".fa-file-o").addClass("fa-file-alt").removeClass("fa-file-o");});
</script>');
echo $OUTPUT->footer();
